@@ -5,22 +5,22 @@ use crate::{
     traits::{FromBytes, ToVec},
 };
 
-pub trait Signature: FromBytes + ToVec + Copy + Clone {}
+pub trait Signature: FromBytes + ToVec + Copy + Clone + PartialEq {}
 
 /// Sign a message.
 pub trait Sign {
-    type S: Signature;
+    type SIG: Signature;
 
     /// Sign a message.
-    fn sign(&self, data: &[u8]) -> Self::S
+    fn sign(&self, data: &[u8]) -> Self::SIG
     where
         Self: Sized;
 }
 
 /// Verify a signature
 pub trait Verify {
-    type S: Signature;
+    type SIG: Signature;
 
     /// Verify a signature
-    fn verify(&self, data: &[u8], signature: &Self::S) -> SignatureResult<()>;
+    fn verify(&self, data: &[u8], signature: &Self::SIG) -> SignatureResult<()>;
 }
